4.59. umbra.ui.widgets.variable_QPushButton — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.59. umbra.ui.widgets.variable_QPushButton

variable_QPushButton.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Variable_QPushButton` class.

Others:

## 4.59.1. Module Attributes

`umbra.ui.widgets.variable_QPushButton.` `LOGGER`

## 4.59.2. Classes

class `umbra.ui.widgets.variable_QPushButton.` `Variable_QPushButton`(parent=None, state=True, colors=(<PyQt4.QtGui.QColor object at 0x10bbcd130>, <PyQt4.QtGui.QColor object at 0x10a693f30>), labels=(u'Yes', u'No'))

  Bases: `PyQt4.QtGui.QPushButton`

  This class is a QPushButton subclass providing a button with different colors and labels depending on its clicked state.

  Parameters: | parent – Widget parent. ( QObject ) state – Current button state. ( Boolean ) colors – Button colors. ( Tuple ) labels – Button texts. ( Tuple )

  `state`

    This method is the property for self.__state attribute.

    Returns: | self.__state. ( Boolean )

  `colors`

    This method is the property for self.__colors attribute.

    Returns: | self.__colors. ( Tuple )

  `labels`

    This method is the property for self.__labels attribute.

    Returns: | self.__labels. ( Tuple )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »